@@ -260,6 +260,7 @@ bool KeyboardWin32::handleEvent(const void* event)
     if (isExtended)
       systemKeyCode |= 0x80;
 
+    systemKeyCode = fixSystemKeyCode(systemKeyCode);
     keyCode = translateSystemKeyCode(systemKeyCode);
 
     GetKeyboardState(state);
@@ -327,7 +328,7 @@ bool KeyboardWin32::handleEvent(const void* event)
   } else if ((msg->message == WM_KEYUP) || (msg->message == WM_SYSKEYUP)) {
     UINT vKey;
     bool isExtended;
-    int systemKeyCode, keyCode;
+    int systemKeyCode;
 
     vKey = msg->wParam;
     isExtended = (msg->lParam & (1 << 24)) != 0;
@@ -355,9 +356,9 @@ bool KeyboardWin32::handleEvent(const void* event)
     if (isExtended)
       systemKeyCode |= 0x80;
 
-    keyCode = translateSystemKeyCode(systemKeyCode);
+    systemKeyCode = fixSystemKeyCode(systemKeyCode);
 
-    handler->handleKeyRelease(keyCode);
+    handler->handleKeyRelease(systemKeyCode);
 
     // Windows has a rather nasty bug where it won't send key release
     // events for a Shift button if the other Shift is still pressed
@@ -553,6 +554,22 @@ void KeyboardWin32::setLEDState(unsigned state)
     vlog.error(_("Failed to update keyboard LED state: %lu"), GetLastError());
 }
 
+int KeyboardWin32::fixSystemKeyCode(int systemKeyCode)
+{
+  // We need stable key codes for everything, but Windows changes the
+  // key code for some keys depending on modifiers
+
+  // Break (Ctrl+Pause) to normal Pause
+  if (systemKeyCode == 0xc6)
+    return 0x45;
+
+  // SysRq (Alt+PrintScreen) to PrintScreen
+  if (systemKeyCode == 0xb7)
+    return 0x54;
+
+  return systemKeyCode;
+}
+
 uint32_t KeyboardWin32::translateSystemKeyCode(int systemKeyCode)
 {
   // Fortunately RFB and Windows use the same scan code set (mostly),
@@ -569,11 +586,6 @@ uint32_t KeyboardWin32::translateSystemKeyCode(int systemKeyCode)
   if (systemKeyCode == 0xc5)
     return 0x45;
 
-  // And Alt+PrintScreen (i.e. SysRq) sends a different code than
-  // PrintScreen
-  if (systemKeyCode == 0xb7)
-    return 0x54;
-
   return systemKeyCode;
 }
 
