@@ -365,20 +365,20 @@ void Viewport::pushLEDState()
   if ((ledState & rfb::ledCapsLock) !=
       (cc->server.ledState() & rfb::ledCapsLock)) {
     vlog.debug("Inserting fake CapsLock to get in sync with server");
-    handleKeyPress(FAKE_KEY_CODE, 0x3a, XK_Caps_Lock);
-    handleKeyRelease(FAKE_KEY_CODE);
+    sendKeyPress(FAKE_KEY_CODE, 0x3a, XK_Caps_Lock);
+    sendKeyRelease(FAKE_KEY_CODE);
   }
   if ((ledState & rfb::ledNumLock) !=
       (cc->server.ledState() & rfb::ledNumLock)) {
     vlog.debug("Inserting fake NumLock to get in sync with server");
-    handleKeyPress(FAKE_KEY_CODE, 0x45, XK_Num_Lock);
-    handleKeyRelease(FAKE_KEY_CODE);
+    sendKeyPress(FAKE_KEY_CODE, 0x45, XK_Num_Lock);
+    sendKeyRelease(FAKE_KEY_CODE);
   }
   if ((ledState & rfb::ledScrollLock) !=
       (cc->server.ledState() & rfb::ledScrollLock)) {
     vlog.debug("Inserting fake ScrollLock to get in sync with server");
-    handleKeyPress(FAKE_KEY_CODE, 0x46, XK_Scroll_Lock);
-    handleKeyRelease(FAKE_KEY_CODE);
+    sendKeyPress(FAKE_KEY_CODE, 0x46, XK_Scroll_Lock);
+    sendKeyRelease(FAKE_KEY_CODE);
   }
 }
 
@@ -524,9 +524,9 @@ int Viewport::handle(int event)
 
     // Resend Ctrl/Alt if needed
     if (menuCtrlKey)
-      handleKeyPress(FAKE_CTRL_KEY_CODE, 0x1d, XK_Control_L);
+      sendKeyPress(FAKE_CTRL_KEY_CODE, 0x1d, XK_Control_L);
     if (menuAltKey)
-      handleKeyPress(FAKE_ALT_KEY_CODE, 0x38, XK_Alt_L);
+      sendKeyPress(FAKE_ALT_KEY_CODE, 0x38, XK_Alt_L);
 
     // Yes, we would like some focus please!
     return 1;
@@ -798,6 +798,12 @@ void Viewport::handleKeyPress(int systemKeyCode,
 
   // Normal key, so send to server...
 
+  sendKeyPress(systemKeyCode, keyCode, keySym);
+}
+
+void Viewport::sendKeyPress(int systemKeyCode,
+                            uint32_t keyCode, uint32_t keySym)
+{
   if (viewOnly)
     return;
 
@@ -860,6 +866,11 @@ void Viewport::handleKeyRelease(int systemKeyCode)
 
   // Normal key, so send to server...
 
+  sendKeyRelease(systemKeyCode);
+}
+
+void Viewport::sendKeyRelease(int systemKeyCode)
+{
   if (viewOnly)
     return;
 
@@ -994,26 +1005,26 @@ void Viewport::popupContextMenu()
     break;
   case ID_CTRL:
     if (m->value())
-      handleKeyPress(FAKE_CTRL_KEY_CODE, 0x1d, XK_Control_L);
+      sendKeyPress(FAKE_CTRL_KEY_CODE, 0x1d, XK_Control_L);
     else
-      handleKeyRelease(FAKE_CTRL_KEY_CODE);
+      sendKeyRelease(FAKE_CTRL_KEY_CODE);
     menuCtrlKey = !menuCtrlKey;
     break;
   case ID_ALT:
     if (m->value())
-      handleKeyPress(FAKE_ALT_KEY_CODE, 0x38, XK_Alt_L);
+      sendKeyPress(FAKE_ALT_KEY_CODE, 0x38, XK_Alt_L);
     else
-      handleKeyRelease(FAKE_ALT_KEY_CODE);
+      sendKeyRelease(FAKE_ALT_KEY_CODE);
     menuAltKey = !menuAltKey;
     break;
   case ID_CTRLALTDEL:
-    handleKeyPress(FAKE_CTRL_KEY_CODE, 0x1d, XK_Control_L);
-    handleKeyPress(FAKE_ALT_KEY_CODE, 0x38, XK_Alt_L);
-    handleKeyPress(FAKE_DEL_KEY_CODE, 0xd3, XK_Delete);
+    sendKeyPress(FAKE_CTRL_KEY_CODE, 0x1d, XK_Control_L);
+    sendKeyPress(FAKE_ALT_KEY_CODE, 0x38, XK_Alt_L);
+    sendKeyPress(FAKE_DEL_KEY_CODE, 0xd3, XK_Delete);
 
-    handleKeyRelease(FAKE_DEL_KEY_CODE);
-    handleKeyRelease(FAKE_ALT_KEY_CODE);
-    handleKeyRelease(FAKE_CTRL_KEY_CODE);
+    sendKeyRelease(FAKE_DEL_KEY_CODE);
+    sendKeyRelease(FAKE_ALT_KEY_CODE);
+    sendKeyRelease(FAKE_CTRL_KEY_CODE);
     break;
   case ID_REFRESH:
     cc->refreshFramebuffer();
