@@ -36,7 +36,7 @@ namespace rfb {
 
     // Wrapper around Win32 MessageBox()
     static int MsgBox(HWND parent, const char* msg, UINT flags) {
-      const char* msgType = 0;
+      const char* msgType = nullptr;
       UINT tflags = flags & 0x70;
       if (tflags == MB_ICONHAND)
         msgType = "Error";
@@ -47,8 +47,6 @@ namespace rfb {
       else if (tflags == MB_ICONASTERISK)
         msgType = "Information";
       flags |= MB_TOPMOST | MB_SETFOREGROUND;
-      int len = strlen(AppName) + 1;
-      if (msgType) len += strlen(msgType) + 3;
       std::string title = AppName;
       if (msgType) {
         title += " : ";
